@@ -31,6 +31,26 @@ var sourceFileTypeStrs = map[SourceFileTargetType]string{
 	SourceFileTypeSymlink: "symlink",
 }
 
+// A ScriptOrder defines when a script should be executed.
+type ScriptOrder int
+
+// Script orders.
+const (
+	ScriptOrderBefore ScriptOrder = -1
+	ScriptOrderDuring ScriptOrder = 0
+	ScriptOrderAfter  ScriptOrder = 1
+)
+
+// A ScriptCondition defines under what conditions a script should be executed.
+type ScriptCondition string
+
+// Script conditions.
+const (
+	ScriptConditionAlways   ScriptCondition = ""
+	ScriptConditionOnce     ScriptCondition = "once"
+	ScriptConditionOnChange ScriptCondition = "onchange"
+)
+
 // DirAttr holds attributes parsed from a source directory name.
 type DirAttr struct {
 	TargetName string
@@ -43,11 +63,11 @@ type DirAttr struct {
 type FileAttr struct {
 	TargetName string
 	Type       SourceFileTargetType
+	Condition  ScriptCondition
 	Empty      bool
 	Encrypted  bool
 	Executable bool
-	Once       bool
-	Order      int
+	Order      ScriptOrder
 	Private    bool
 	ReadOnly   bool
 	Template   bool
@@ -136,14 +156,14 @@ func parseFileAttr(sourceName, encryptedSuffix string) FileAttr {
 	var (
 		sourceFileType = SourceFileTypeFile
 		name           = sourceName
+		condition      = ScriptConditionAlways
 		empty          = false
 		encrypted      = false
 		executable     = false
-		once           = false
+		order          = ScriptOrderDuring
 		private        = false
 		readOnly       = false
 		template       = false
-		order          = 0
 	)
 	switch {
 	case strings.HasPrefix(name, createPrefix):
@@ -171,17 +191,21 @@ func parseFileAttr(sourceName, encryptedSuffix string) FileAttr {
 	case strings.HasPrefix(name, runPrefix):
 		sourceFileType = SourceFileTypeScript
 		name = mustTrimPrefix(name, runPrefix)
-		if strings.HasPrefix(name, oncePrefix) {
+		switch {
+		case strings.HasPrefix(name, oncePrefix):
 			name = mustTrimPrefix(name, oncePrefix)
-			once = true
+			condition = ScriptConditionOnce
+		case strings.HasPrefix(name, onChangePrefix):
+			name = mustTrimPrefix(name, onChangePrefix)
+			condition = ScriptConditionOnChange
 		}
 		switch {
 		case strings.HasPrefix(name, beforePrefix):
 			name = mustTrimPrefix(name, beforePrefix)
-			order = -1
+			order = ScriptOrderBefore
 		case strings.HasPrefix(name, afterPrefix):
 			name = mustTrimPrefix(name, afterPrefix)
-			order = 1
+			order = ScriptOrderAfter
 		}
 	case strings.HasPrefix(name, symlinkPrefix):
 		sourceFileType = SourceFileTypeSymlink
@@ -249,14 +273,14 @@ func parseFileAttr(sourceName, encryptedSuffix string) FileAttr {
 	return FileAttr{
 		TargetName: name,
 		Type:       sourceFileType,
+		Condition:  condition,
 		Empty:      empty,
 		Encrypted:  encrypted,
 		Executable: executable,
-		Once:       once,
+		Order:      order,
 		Private:    private,
 		ReadOnly:   readOnly,
 		Template:   template,
-		Order:      order,
 	}
 }
 
@@ -265,11 +289,11 @@ func parseFileAttr(sourceName, encryptedSuffix string) FileAttr {
 func (fa FileAttr) MarshalZerologObject(e *zerolog.Event) {
 	e.Str("TargetName", fa.TargetName)
 	e.Str("Type", sourceFileTypeStrs[fa.Type])
+	e.Str("Condition", string(fa.Condition))
 	e.Bool("Empty", fa.Empty)
 	e.Bool("Encrypted", fa.Encrypted)
 	e.Bool("Executable", fa.Executable)
-	e.Bool("Once", fa.Once)
-	e.Int("Order", fa.Order)
+	e.Int("Order", int(fa.Order))
 	e.Bool("Private", fa.Private)
 	e.Bool("ReadOnly", fa.ReadOnly)
 	e.Bool("Template", fa.Template)
@@ -324,13 +348,16 @@ func (fa FileAttr) SourceName(encryptedSuffix string) string {
 		sourceName = removePrefix
 	case SourceFileTypeScript:
 		sourceName = runPrefix
-		if fa.Once {
+		switch fa.Condition {
+		case ScriptConditionOnce:
 			sourceName += oncePrefix
+		case ScriptConditionOnChange:
+			sourceName += onChangePrefix
 		}
 		switch fa.Order {
-		case -1:
+		case ScriptOrderBefore:
 			sourceName += beforePrefix
-		case 1:
+		case ScriptOrderAfter:
 			sourceName += afterPrefix
 		}
 	case SourceFileTypeSymlink:
