@@ -122,13 +122,13 @@ type Config struct {
 	keyring keyringData
 
 	// Command configurations, settable in the config file.
-	Add   addCmdConfig   `mapstructure:"add"`
-	CD    cdCmdConfig    `mapstructure:"cd"`
-	Diff  diffCmdConfig  `mapstructure:"diff"`
-	Docs  docsCmdConfig  `mapstructure:"docs"`
-	Edit  editCmdConfig  `mapstructure:"edit"`
-	Git   gitCmdConfig   `mapstructure:"git"`
-	Merge mergeCmdConfig `mapstructure:"merge"`
+	Add        addCmdConfig        `mapstructure:"add"`
+	CD         cdCmdConfig         `mapstructure:"cd"`
+	Completion completionCmdConfig `mapstructure:"completion"`
+	Diff       diffCmdConfig       `mapstructure:"diff"`
+	Edit       editCmdConfig       `mapstructure:"edit"`
+	Git        gitCmdConfig        `mapstructure:"git"`
+	Merge      mergeCmdConfig      `mapstructure:"merge"`
 
 	// Command configurations, not settable in the config file.
 	apply           applyCmdConfig
@@ -304,9 +304,6 @@ func newConfig(options ...configOption) (*Config, error) {
 			Exclude: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
 			include: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
 		},
-		Docs: docsCmdConfig{
-			MaxWidth: 80,
-		},
 		Edit: editCmdConfig{
 			Hardlink:    true,
 			MinDuration: 1 * time.Second,
@@ -1326,7 +1323,6 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newDataCmd(),
 		c.newDecryptCommand(),
 		c.newDiffCmd(),
-		c.newDocsCmd(),
 		c.newDoctorCmd(),
 		c.newDumpCmd(),
 		c.newEditCmd(),
@@ -1954,6 +1950,10 @@ func (c *Config) targetRelPathsBySourcePath(
 func (c *Config) targetValidArgs(
 	cmd *cobra.Command, args []string, toComplete string,
 ) ([]string, cobra.ShellCompDirective) {
+	if !c.Completion.Custom {
+		return nil, cobra.ShellCompDirectiveDefault
+	}
+
 	toCompleteAbsPath, err := chezmoi.NewAbsPathFromExtPath(toComplete, c.homeDirAbsPath)
 	if err != nil {
 		cobra.CompErrorln(err.Error())
@@ -1969,6 +1969,9 @@ func (c *Config) targetValidArgs(
 	var completions []string
 	if err := sourceState.ForEach(func(targetRelPath chezmoi.RelPath, sourceStateEntry chezmoi.SourceStateEntry) error {
 		completion := c.DestDirAbsPath.Join(targetRelPath).String()
+		if _, ok := sourceStateEntry.(*chezmoi.SourceStateDir); ok {
+			completion += "/"
+		}
 		if strings.HasPrefix(completion, toCompleteAbsPath.String()) {
 			completions = append(completions, completion)
 		}
